==> LUSScreenSaverUtil_1.1.0_src.tar.gz: LUSScreenSaverUtil/LUSScreenSaverUtilBase.h <==
/*
	LUSScreenSaver Plugin Interface
	Copyright (C) 2003 ONO,Masayuki.<mono101@skill-engineering.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef __LESS_UNSATICEFACTORY_SCREENSAVER_UTIL_BASE_H__
#define __LESS_UNSATICEFACTORY_SCREENSAVER_UTIL_BASE_H__

#include <qvariant.h>
#include <qdialog.h>
#include <qpe/qpeapplication.h>

class QTabWidget;
class QVBoxLayout; 
class QHBoxLayout; 
class QBoxLayout; 
class QGridLayout; 
class QComboBox;
class QGroupBox;
class QLabel;
class QMultiLineEdit;
class QPushButton;
class QSlider;
class QCheckBox;

class LUSScreenSaverUtilBase : public QDialog
{ 
Q_OBJECT

public:
	LUSScreenSaverUtilBase( QWidget* parent = 0, const char* name = 0,
									bool modal = FALSE, WFlags fl = 0 );
	~LUSScreenSaverUtilBase();

	QTabWidget*		Tabs;

	QWidget*		Tab1;
	QGroupBox*		BasicGroupBox;
	QCheckBox*		TrayIconCheck;
	QLabel*			SliderLabel;
	QSlider*		IntervalSlider;
	QGroupBox*		ModuleGroupBox;
	QComboBox*		ModuleSelectCombo;
	QMultiLineEdit*	PropertyDisplay;

	QWidget*		Tab2;
	QPushButton*	SettingButton;
	QLabel*			PreviewWindow;

protected:
	QVBoxLayout*	BaseFormLayout;
	QVBoxLayout*	TabBaseLayout1;
	QVBoxLayout*	TabBaseLayout2;
	QVBoxLayout*	ModuleGroupBoxLayout;
	QVBoxLayout*	BasicGroupBoxLayout;
};

#endif // __LESS_UNSATICEFACTORY_SCREENSAVER_UTIL_BASE_H__

==> LUSScreenSaverUtil_1.2.0-1_src.tar.gz: LUSScreenSaverUtil/LUSScreenSaverUtilBase.h <==
/*
	LUSScreenSaverUtil
	Copyright (C) 2003 ONO,Masayuki.<mono101@skill-engineering.com>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef __LESS_UNSATICEFACTORY_SCREENSAVER_UTIL_BASE_H__
#define __LESS_UNSATICEFACTORY_SCREENSAVER_UTIL_BASE_H__

#include <qvariant.h>
#include <qdialog.h>
#include <qpe/qpeapplication.h>

class QTabWidget;
class QLineEdit;
class QVBoxLayout; 
class QHBoxLayout; 
class QBoxLayout; 
class QGridLayout; 
class QComboBox;
class QGroupBox;
class QLabel;
class QMultiLineEdit;
class QPushButton;
class QSlider;
class QCheckBox;

class LUSScreenSaverUtilBase : public QDialog
{ 
Q_OBJECT

public:
	LUSScreenSaverUtilBase( QWidget* parent = 0, const char* name = 0,
									bool modal = FALSE, WFlags fl = 0 );
	~LUSScreenSaverUtilBase();

	QTabWidget*		Tabs;

	QWidget*		Tab1;
	QGroupBox*		BasicGroupBox;
	QCheckBox*		TrayIconCheck;
	QLabel*			SliderLabel;
	QSlider*		IntervalSlider;
	QLabel*			DisSuspendLabel;
	QLineEdit*		DisSuspendApp;
	QLabel*			DisScreenSavingLabel;
	QLineEdit*		DisScreenSavingApp;

	QWidget*		Tab3;
	QGroupBox*		ModuleGroupBox;
	QComboBox*		ModuleSelectCombo;
	QPushButton*	SettingButton;
	QMultiLineEdit*	PropertyDisplay;
	
	QWidget*		Tab2;
	QLabel*			PreviewWindow;

protected:
	QVBoxLayout*	BaseFormLayout;
	QVBoxLayout*	TabBaseLayout1;
	QVBoxLayout*	TabBaseLayout2;
	QVBoxLayout*	TabBaseLayout3;
	QVBoxLayout*	ModuleGroupBoxLayout;
	QVBoxLayout*	BasicGroupBoxLayout;
};

#endif // __LESS_UNSATICEFACTORY_SCREENSAVER_UTIL_BASE_H__
